"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JP2 = void 0;
const interface_1 = require("./interface");
const BoxTypes = {
    ftyp: '66747970',
    ihdr: '69686472',
    jp2h: '6a703268',
    jp__: '6a502020',
    rreq: '72726571',
    xml_: '786d6c20'
};
const calculateRREQLength = (box) => {
    const unit = box[0];
    let offset = 1 + (2 * unit);
    const numStdFlags = (0, interface_1.readUInt16BE)(box, offset);
    const flagsLength = numStdFlags * (2 + unit);
    offset = offset + 2 + flagsLength;
    const numVendorFeatures = (0, interface_1.readUInt16BE)(box, offset);
    const featuresLength = numVendorFeatures * (16 + unit);
    return offset + 2 + featuresLength;
};
const parseIHDR = (box) => {
    return {
        height: (0, interface_1.readUInt32BE)(box, 4),
        width: (0, interface_1.readUInt32BE)(box, 8),
    };
};
exports.JP2 = {
    validate(input) {
        const signature = (0, interface_1.toHexString)(input, 4, 8);
        const signatureLength = (0, interface_1.readUInt32BE)(input, 0);
        if (signature !== BoxTypes.jp__ || signatureLength < 1) {
            return false;
        }
        const ftypeBoxStart = signatureLength + 4;
        const ftypBoxLength = (0, interface_1.readUInt32BE)(input, signatureLength);
        const ftypBox = input.slice(ftypeBoxStart, ftypeBoxStart + ftypBoxLength);
        return (0, interface_1.toHexString)(ftypBox, 0, 4) === BoxTypes.ftyp;
    },
    calculate(input) {
        const signatureLength = (0, interface_1.readUInt32BE)(input, 0);
        const ftypBoxLength = (0, interface_1.readUInt16BE)(input, signatureLength + 2);
        let offset = signatureLength + 4 + ftypBoxLength;
        const nextBoxType = (0, interface_1.toHexString)(input, offset, offset + 4);
        switch (nextBoxType) {
            case BoxTypes.rreq:
                // WHAT ARE THESE 4 BYTES?????
                // eslint-disable-next-line no-case-declarations
                const MAGIC = 4;
                offset = offset + 4 + MAGIC + calculateRREQLength(input.slice(offset + 4));
                return parseIHDR(input.slice(offset + 8, offset + 24));
            case BoxTypes.jp2h:
                return parseIHDR(input.slice(offset + 8, offset + 24));
            default:
                throw new TypeError('Unsupported header found: ' + (0, interface_1.toUTF8String)(input, offset, offset + 4));
        }
    }
};
